scxpand.data\_util.statistics
=============================

.. automodule:: scxpand.data_util.statistics

   
   .. rubric:: Functions

   .. autosummary::
   
      compute_preprocessed_genes_means_stds
   